<?php

/**
 * @package    WPBuddy Plugin
 * @subpackage Google+ Author
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
} // Exit if accessed directly


/**
 * Echoes out the Metabox contents
 * @since 1.0
 */
class WPB_Google_Author_Metaboxes {

	/**
	 * @var null|WPB_Google_Author
	 */
	private $_google_author = null;


	/**
	 * @param WPB_Google_Author $google_author
	 *
	 * @return \WPB_Google_Author_Metaboxes
	 * @since 1.0
	 */
	public function __construct( &$google_author ) {
		$this->_google_author = $google_author;
	}


	/**
	 * creates the content for the general metabox
	 * shows some information on the plugin
	 *
	 * @access public
	 *
	 * @return void
	 * @since  1.0
	 */
	public function general() {

		echo '<p>' . __( 'This plugin will replace your author link in your theme with your Google+ Profile link to make sure that your Google+ profile picture will be shown in Google News and/or Googles search results.', $this->_google_author->get_textdomain() ) . '</p>';

		echo '<p>' . __( 'Alternatively the link can be included in the content or in the head-section if your theme does not show the author link to the public.', $this->_google_author->get_textdomain() ) . '</p>';

	}


	/**
	 * creates the content for the howto-metabox
	 *
	 * @access public
	 *
	 * @return void
	 * @since  1.0
	 */
	public function howto() {
		?>
		<h4><?php echo __( 'A) Set up authorship by linking your content to your Google+ profile', $this->_google_author->get_textdomain() ); ?></h4>

		<ol id="gplisting">

			<li><?php echo sprintf( __( 'Follow this link to open your Google+ profile: %s', $this->_google_author->get_textdomain() ), '<a href="http://plus.google.com/me" target="_blank">http://plus.google.com/me</a>' ); ?></li>

			<li><?php echo __( 'Copy your Profile-URL from the address bar to clipboard (see picture below):', $this->_google_author->get_textdomain() ); ?>
				<br />
				<img src="<?php echo $this->_google_author->plugins_url( 'assets/img/gplus-profile.jpg' ); ?>" alt="" style="border: 1px solid black;" />
			</li>

			<li><?php echo sprintf( __( 'Go to your WordPress Admin Panel and click Users &raquo; %s. Paste the above mentioned URL to the field where it says "Google+" in the "Contact Info" section.', $this->_google_author->get_textdomain() ), '<a href="" target="_blank">' . __( 'Your Profile', $this->_google_author->get_textdomain() ) . '</a>' ); ?>
				<br />
				<img src="<?php echo $this->_google_author->plugins_url( 'assets/img/gplus-profile-update.jpg' ); ?>" alt="" style="border: 1px solid black;" />
			</li>

			<li><?php echo __( 'Click Update Profile.', $this->_google_author->get_textdomain() ); ?></li>

			<li><?php echo __( 'Repeat the above steps with all the other WordPress authors on your blog.', $this->_google_author->get_textdomain() ); ?></li>

		</ol>

		<br />
		<h4><?php echo __( 'B) Add a reciprocal link back from your profile to the site you just updated', $this->_google_author->get_textdomain() ); ?></h4>

		<ol id="gplisting">

			<li><?php echo sprintf( __( 'Follow this link to edit the "Contributor To" section: %s', $this->_google_author->get_textdomain() ), '<a href="http://plus.google.com/me/about/edit/co" target="_blank">http://plus.google.com/me/about/edit/co</a>' ); ?></li>

			<li><?php echo sprintf( __( 'A dialog will appear. Scroll down to the "Contributor to" section. Click "Add custom link" and enter your website URL: %s', $this->_google_author->get_textdomain() ), site_url() ); ?></li>

			<li><?php echo sprintf( __( 'Optional: For the label you can use your website title: %s', $this->_google_author->get_textdomain() ), get_bloginfo( 'name' ) ); ?></li>

			<li><?php echo __( 'If you want, click the drop-down list to specify who can see the link.', $this->_google_author->get_textdomain() ); ?></li>

			<li><?php echo __( 'Click Save.', $this->_google_author->get_textdomain() ); ?></li>

			<li><?php echo __( 'Tell your authors that they should also do step B.', $this->_google_author->get_textdomain() ); ?></li>

		</ol>

		<br />
		<h4><?php echo __( 'C) Test', $this->_google_author->get_textdomain() ); ?></h4>

		<ol id="gplisting">

			<li><?php echo __( 'To see what author data Google can extract from your page, use the Rich Snippet Testing Tool. For this use the buttons in the Test-Area on this page.', $this->_google_author->get_textdomain() ); ?></li>


			<li><?php echo __( 'If Google cannot extract your profile picture and/or your name, please read the FAQ which you can find on our website:', 'gpaisrpro' ) . ' <a href="http://wp-buddy.com/inlink/google-author-be-faq" target="_blank">' . __( 'Open the documentation now.', $this->_google_author->get_textdomain() ) . '</a>'; ?></li>


		</ol>
	<?php
	}


	/**
	 * creates the content for the settings metabox
	 *
	 * @access public
	 *
	 * @return void
	 * @since  1.0
	 */
	public function settings() {

		do_settings_sections( 'gpaisrpro' );

		submit_button();

		echo '<div class="clear"></div>';

	}


	/**
	 * creates the content for the "test" side-metabox
	 *
	 * @access public
	 *
	 * @return void
	 * @since  1.0
	 */
	public function test() {

		do_settings_sections( 'gpaisrpro_test' );

		echo '<ol class="gpaisrpro-test-results"></ol>';
	}

	/**
	 * The "about" metabox
	 * @since 1.2
	 * @return void
	 */
	public function about() {
		?>
		<a href="http://wp-buddy.com/inlink/google-author-be-wpbuddy" target="_blank"><img src="https://wpbuddy.libra.uberspace.de/secure/wp-buddy-logo.png" alt="WPBuddy Logo" /></a><?php
	}


	/**
	 * Outputs the metabox content for the links
	 * @since 1.2
	 * @return void
	 */
	public function links() {
		?>
		<ul>
			<li>
				<a href="http://wp-buddy.com/inlink/google-author-be-installation-manual" target="_blank"><?php echo __( 'Installation manual', $this->_google_author->get_textdomain() ); ?></a>
			</li>
			<li>
				<a href="http://wp-buddy.com/inlink/google-author-be-faq" target="_blank"><?php echo __( 'Frequently Asked Questions', $this->_google_author->get_textdomain() ); ?></a>
			</li>
			<li>
				<a href="http://wp-buddy.com/inlink/google-author-be-report-a-bug" target="_blank"><?php echo __( 'Report a bug', $this->_google_author->get_textdomain() ); ?></a>
			</li>
			<li>
				<a href="http://wp-buddy.com/inlink/google-author-be-request-a-function" target="_blank"><?php echo __( 'Request a function', $this->_google_author->get_textdomain() ); ?></a>
			</li>
			<li>
				<a href="http://wp-buddy.com/inlink/google-author-be-submit-a-translation" target="_blank"><?php echo __( 'Submit a translation', $this->_google_author->get_textdomain() ); ?></a>
			</li>
			<li>
				<a href="http://wp-buddy.com/inlink/google-author-be-products" target="_blank"><?php echo __( 'More cool stuff by WPBuddy', $this->_google_author->get_textdomain() ); ?></a>
			</li>
		</ul>
	<?php
	}


	/**
	 * Outputs the metabox content for the social links
	 * @return void
	 * @since 1.2
	 */
	public function social() {
		?>
		<div class="wpbr-social">

			<!-- Facebook button -->
			<p>
				<iframe src="//www.facebook.com/plugins/like.php?href=<?php echo urlencode( 'http://wp-buddy.com/products/plugins/google-authorship-wordpress-plugin/' ); ?>&layout=button_count&amp;width=150&amp;show_faces=true&amp;font&amp;colorscheme=light&amp;action=like&amp;height=21" scrolling="no" frameborder="0" style="border:none; overflow:hidden; width:150px; height:25px;" allowTransparency="true"></iframe>
			</p>

			<!-- Twitter-Button -->
			<p>
				<a href="https://twitter.com/share" class="twitter-share-button" data-url="http://wp-buddy.com/products/plugins/google-authorship-wordpress-plugin/" data-text="Google Plus Authorship WordPress Plugin" data-related="wp_buddy">Tweet</a>
				<script>!function (d, s, id) {
						var js, fjs = d.getElementsByTagName(s)[0];
						if (!d.getElementById(id)) {
							js = d.createElement(s);
							js.id = id;
							js.src = "//platform.twitter.com/widgets.js";
							fjs.parentNode.insertBefore(js, fjs);
						}
					}(document, "script", "twitter-wjs");</script>
			</p>

			<!-- Google+ Button -->
			<p>

			<div class="g-plusone" data-size="medium" data-href="http://wp-buddy.com/products/plugins/google-authorship-wordpress-plugin/"></div>
			<script type="text/javascript">
				(function () {
					var po = document.createElement('script');
					po.type = 'text/javascript';
					po.async = true;
					po.src = 'https://apis.google.com/js/plusone.js';
					var s = document.getElementsByTagName('script')[0];
					s.parentNode.insertBefore(po, s);
				})();
			</script>
			</p>

		</div>
	<?php
	}


	/**
	 * @since 1.2
	 */
	public function subscribe() {
		global $current_user;
		get_currentuserinfo();
		$name = $current_user->user_firstname;
		if ( empty( $name ) ) {
			$name = $current_user->display_name;
		}
		?>
		<div class="wpbuddy-cr-form">
			<label for="text1210658"><?php echo __( 'Your first name', $this->_google_author->get_textdomain() ); ?></label>
			<input id="text1210658" name="209681" type="text" value="<?php echo $name; ?>" />
			<label for="text1210692"><?php echo __( 'Your E-Mail address', $this->_google_author->get_textdomain() ); ?></label>
			<input id="text1210692" name="email" value="<?php echo $current_user->user_email; ?>" type="text" />
			<a href="https://10955.cleverreach.com/f/54067/wcs/" target="_blank" class="button button-primary"><?php echo __( 'Subscribe', $this->_google_author->get_textdomain() ); ?></a>
		</div>
	<?php
	}


	/**
	 * @since 2.4.6
	 */
	public function settings_publisher() {
		do_settings_sections( 'gpaisrpro_settings_publisher' );

		submit_button();

		echo '<div class="clear"></div>';
	}


	/**
	 * @since 2.4.6
	 */
	public function settings_general() {
		do_settings_sections( 'gpaisrpro_settings_general' );

		submit_button();

		echo '<div class="clear"></div>';
	}

}