<?php

/**
 * @package    WPBuddy Plugin
 * @subpackage Google+ Author
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
} // Exit if accessed directly


/**
 * Handles the settings of the plugin
 * @since 1.3
 */
class WPB_Google_Author_Settings {


	/**
	 * @var null|WPB_Google_Author
	 */
	private $_google_author = null;


	/**
	 * @param WPB_Google_Author $google_author
	 *
	 * @return \WPB_Google_Author_Settings
	 * @since 1.0
	 */
	public function __construct( &$google_author ) {
		$this->_google_author = $google_author;
	}


	/**
	 * settings function.
	 * creates the settings-fields in the settings-metaboxes
	 *
	 * @access public
	 * @return void
	 * @since  1.0
	 */
	function settings() {
		register_setting( 'gpaisrpro_options_group', 'gpaisrpro' );


		/**
		 * Test settings
		 */

		add_settings_section(
			'gpaisrpro_section_test',
			'',
			array( &$this, 'sectionText' ),
			'gpaisrpro_test'
		);

		add_settings_field(
			'gpaisrpro_post_types',
			__( 'Post/Page to test', $this->_google_author->get_textdomain() ),
			array( &$this, 'field_posts' ),
			'gpaisrpro_test',
			'gpaisrpro_section_test'
		);


		/**
		 * Author Settings
		 */

		add_settings_section(
			'gpaisrpro_section_text',
			'',
			array( &$this, 'sectionText' ),
			'gpaisrpro'
		);

		add_settings_field(
			'gpaisrpro_googleplus_frontpage_users',
			__( 'Frontpage authors', $this->_google_author->get_textdomain() ),
			array( &$this, 'field_google_plus_frontpage_users' ),
			'gpaisrpro',
			'gpaisrpro_section_text',
			array( 'label_for' => 'google_plus_frontpage_users' )
		);

		add_settings_field(
			'gpaisrpro_googleplus_category_users',
			__( 'Category authors', $this->_google_author->get_textdomain() ),
			array( &$this, 'field_google_plus_category_users' ),
			'gpaisrpro',
			'gpaisrpro_section_text',
			array( 'label_for' => 'google_plus_category_users' )
		);

		add_settings_field(
			'gpaisrpro_googleplus_tag_users',
			__( 'Tag authors', $this->_google_author->get_textdomain() ),
			array( &$this, 'field_google_plus_tag_users' ),
			'gpaisrpro',
			'gpaisrpro_section_text',
			array( 'label_for' => 'google_plus_tag_users' )
		);

		add_settings_field(
			'gpaisrpro_post_types',
			__( 'Choose the post types to use with the plugin', $this->_google_author->get_textdomain() ),
			array( &$this, 'field_post_types' ),
			'gpaisrpro',
			'gpaisrpro_section_text',
			array( 'label_for' => 'test_post_id' )
		);

		add_settings_field(
			'gpaisrpro_replace_author_link',
			__( 'Standard Integration', $this->_google_author->get_textdomain() ),
			array( &$this, 'field_replacement' ),
			'gpaisrpro',
			'gpaisrpro_section_text',
			array( 'label_for' => 'gpaisrpro_replace_author_link_1' )
		);

		add_settings_field(
			'gpaisrpro_hide_author_link_in_content',
			__( 'Show or hide the link?', $this->_google_author->get_textdomain() ),
			array( &$this, 'field_hide' ),
			'gpaisrpro',
			'gpaisrpro_section_text',
			array( 'label_for' => 'gpaisrpro_replace_hide_1' )
		);

		add_settings_field(
			'gpaisrpro_before_after_content',
			__( 'Where to show the link in the content', $this->_google_author->get_textdomain() ),
			array( &$this, 'field_before_after_content' ),
			'gpaisrpro',
			'gpaisrpro_section_text',
			array( 'label_for' => 'gpaisrpro_before_after' )
		);

		add_settings_field(
			'gpaisrpro_open_in_new_window',
			__( 'Open the link in a new window?', $this->_google_author->get_textdomain() ),
			array( &$this, 'field_new_window' ),
			'gpaisrpro',
			'gpaisrpro_section_text',
			array( 'label_for' => 'gpaisrpro_new_window' )
		);

		add_settings_field(
			'gpaisrpro_link_text',
			__( 'Link text', $this->_google_author->get_textdomain() ),
			array( &$this, 'field_link_text' ),
			'gpaisrpro',
			'gpaisrpro_section_text',
			array( 'label_for' => 'gpaisrpro_link_text' )
		);

		add_settings_field(
			'gpaisrpro_hidden_fields',
			'',
			array( &$this, 'fields_hidden' ),
			'gpaisrpro',
			'gpaisrpro_section_text',
			array( 'label_for' => 'gpaisrpro_hidden_fields' )
		);

		add_settings_field(
			'gpaisrpro_rss',
			__( 'Display in Feed?', $this->_google_author->get_textdomain() ),
			array( &$this, 'field_rss' ),
			'gpaisrpro',
			'gpaisrpro_section_text',
			array( 'label_for' => 'gpaisrpro_in_feed' )
		);


		/**
		 * Publisher Settings
		 */

		add_settings_section(
			'gpaisrpro_section_publisher',
			'',
			array( &$this, 'sectionText' ),
			'gpaisrpro_settings_publisher'
		);

		add_settings_field(
			'gpaisrpro_googleplus_page',
			__( 'Google+ Page URL', $this->_google_author->get_textdomain() ),
			array( &$this, 'field_google_plus_page_url' ),
			'gpaisrpro_settings_publisher',
			'gpaisrpro_section_publisher',
			array( 'label_for' => 'google_plus_page_url' )
		);

		add_settings_field(
			'gpaisrpro_googleplus_page_header',
			__( 'Standard Integration', $this->_google_author->get_textdomain() ),
			array( &$this, 'field_google_plus_page_header' ),
			'gpaisrpro_settings_publisher',
			'gpaisrpro_section_publisher',
			array( 'label_for' => 'google_plus_page_header' )
		);

		add_settings_field(
			'gpaisrpro_googleplus_page_text',
			__( 'Google+ Page Link text', $this->_google_author->get_textdomain() ),
			array( &$this, 'field_google_plus_page_text' ),
			'gpaisrpro_settings_publisher',
			'gpaisrpro_section_publisher',
			array( 'label_for' => 'google_plus_page_text' )
		);

		add_settings_field(
			'gpaisrpro_googleplus_page_styles',
			__( 'Link styles', $this->_google_author->get_textdomain() ),
			array( &$this, 'field_google_plus_page_styles' ),
			'gpaisrpro_settings_publisher',
			'gpaisrpro_section_publisher',
			array( 'label_for' => 'field_google_plus_page_styles' )
		);


		/**
		 *  General Settings
		 */

		add_settings_section(
			'gpaisrpro_section_general',
			'',
			array( &$this, 'sectionText' ),
			'gpaisrpro_settings_general'
		);

		add_settings_field(
			'gpaisrpro_purchase_code',
			__( 'Purchase Code', $this->_google_author->get_textdomain() ),
			array( &$this, 'field_purchase_code' ),
			'gpaisrpro_settings_general',
			'gpaisrpro_section_general',
			array( 'label_for' => 'gpaisrpro_purchase_code' )
		);

	}


	/**
	 * sectionText function.
	 * this is a text-section
	 *
	 * @access public
	 * @return void
	 * @since  1.0
	 */
	function sectionText() {
	}


	/**
	 * field_replacement function.
	 * shows the replacement-settings field
	 *
	 * @access public
	 * @return void
	 * @since  1.0
	 */
	function field_replacement() {

		// get the options
		$options = get_option( 'gpaisrpro' );

		// check if the option was set. if not set 0 to show that the link should be included into the content
		if ( ! isset( $options['replacement'] ) ) {
			$options['replacement'] = 3;
		}

		echo "<input " . ( ( $options['replacement'] == 1 ) ? 'checked="checked"' : '' ) . " id='gpaisrpro_replace_author_link_1' name='gpaisrpro[replacement]' type='radio' value='1' /> <label for=\"gpaisrpro_replace_author_link_1\">" . __( 'Replace author link with the authors Google+ link', $this->_google_author->get_textdomain() ) . '</label> <span class="description">(' . __( 'This will probably not work with some themes.', $this->_google_author->get_textdomain() ) . ')</span>';

		echo "<br /><input " . ( ( $options['replacement'] == 3 ) ? 'checked="checked"' : '' ) . " id='gpaisrpro_replace_author_link_3' name='gpaisrpro[replacement]' type='radio' value='3' /> <label for=\"gpaisrpro_replace_author_link_3\">" . __( 'Put it into the header', $this->_google_author->get_textdomain() ) . '</label> <span class="description">(' . __( 'This is not visible to the visitors but for Google only. <strong>recommended option</strong>.', $this->_google_author->get_textdomain() ) . ')</span>';

		echo "<br /><input " . ( ( $options['replacement'] == 2 ) ? 'checked="checked"' : '' ) . " id='gpaisrpro_replace_author_link_2' name='gpaisrpro[replacement]' type='radio' value='2' /> <label for=\"gpaisrpro_replace_author_link_2\">" . __( 'Show the link in the widget-area.', $this->_google_author->get_textdomain() ) . '</label>  <span class="description">(' . __( 'Please save this settings and go to your widget settings to add the widget.', $this->_google_author->get_textdomain() ) . ')</span>';

		echo "<br /><input " . ( ( empty( $options['replacement'] ) ) ? 'checked="checked"' : '' ) . " id='gpaisrpro_replace_author_link_0' name='gpaisrpro[replacement]' type='radio' value='0' /> <label for=\"gpaisrpro_replace_author_link_0\">" . __( 'Show it in the content-area', $this->_google_author->get_textdomain() ) . '</label> <span class="description">(' . __( 'See the settings below for more information', $this->_google_author->get_textdomain() ) . ')</span>';

		echo '<p class="description">' . __( 'Not every theme shows the Author-Link right beside a page or a post. In this case activate the link to be included in the content.', $this->_google_author->get_textdomain() ) . '</p>';

	}


	/**
	 * field_hide function.
	 * displays the show or hide settings field
	 *
	 * @access public
	 * @return void
	 * @since  1.0
	 */
	function field_hide() {

		// get the options
		$options = get_option( 'gpaisrpro' );

		if ( ! isset( $options['hide'] ) ) {
			$options['hide'] = 0;
		}

		echo "<input " . ( ( $options['hide'] == 1 ) ? 'checked="checked"' : '' ) . " id='gpaisrpro_replace_hide_1' name='gpaisrpro[hide]'  type='radio' value='1' /> " . __( 'Hide' );

		echo "<br /><input " . ( ( empty( $options['hide'] ) ) ? 'checked="checked"' : '' ) . " id='gpaisrpro_replace_hide_0' name='gpaisrpro[hide]'  type='radio' value='0' /> " . __( 'Show' );

		echo '<p class="description">' . __( 'Please note that Google does not like hidden links.', $this->_google_author->get_textdomain() ) . '</p>';

	}


	/**
	 * field_before_after_content
	 * displays the show or hide settings field
	 *
	 * @access public
	 * @return void
	 * @since  1.0
	 */
	function field_before_after_content() {

		// get the options
		$options = get_option( 'gpaisrpro' );

		// if nothing was set: posts and pages are standard
		if ( ! isset( $options['before_after'] ) ) {
			$options['before_after'] = 'after';
		}

		$possibilities = array(
			'before' => __( 'Before the content', $this->_google_author->get_textdomain() ),
			'after'  => __( 'After the content', $this->_google_author->get_textdomain() ),
			'all'    => __( 'Before and after the content', $this->_google_author->get_textdomain() ),
		);

		?>
		<select size="1" style="width:200px;" name="gpaisrpro[before_after]" id="gpaisrpro_before_after" >
			<?php
			foreach ( $possibilities as $possibility => $text ) {
				echo '<option ' . ( ( $possibility == $options['before_after'] ) ? 'selected="selected"' : '' ) . ' value="' . $possibility . '">' . $text . '</option>';
			}
			?>
		</select>
	<?php
	}


	/**
	 * field_hide function.
	 * displays the show or hide settings field
	 *
	 * @access public
	 * @return void
	 * @since  1.0
	 */
	function field_post_types() {

		// get the options
		$options = get_option( 'gpaisrpro' );

		// if nothing was set: posts and pages are standard
		if ( ! isset( $options['post_types'] ) ) {
			$options['post_types'] = array( 'post', 'page' );
		}

		?>
		<select multiple="multiple" class="chzn-select" style="width:300px;" name="gpaisrpro[post_types][]">
			<?php
			foreach ( get_post_types( array( 'public' => true, 'show_ui' => true ), 'objects' ) as $post_type ) {
				echo '<option ' . ( ( in_array( $post_type->name, $options['post_types'] ) ) ? 'selected="selected"' : '' ) . ' value="' . $post_type->name . '">' . $post_type->labels->name . '</option>';
			}
			?>
		</select>
	<?php
	}


	/**
	 * field_new_window function.
	 * shows the new window settings field
	 *
	 * @access public
	 * @return void
	 * @since  1.0
	 */
	function field_new_window() {

		// get the options
		$options = get_option( 'gpaisrpro' );

		echo "<input " . ( ( isset( $options['new_window'] ) && $options['new_window'] == 1 ) ? 'checked="checked"' : '' ) . " id='gpaisrpro_new_window' name='gpaisrpro[new_window]'  type='checkbox' value='1' />";

	}


	/**
	 * field_rss function.
	 * shows the "no rss" settings field
	 *
	 * @access public
	 * @return void
	 */
	function field_rss() {

		// get the options
		$options = get_option( 'gpaisrpro' );

		echo "<input " . ( ( isset( $options['in_feed'] ) && $options['in_feed'] == 1 ) ? 'checked="checked"' : '' ) . " id='gpaisrpro_in_feed' name='gpaisrpro[in_feed]'  type='checkbox' value='1' />";
	}


	/**
	 * field_link_text function.
	 * displays the link text settings field
	 *
	 * @access public
	 * @return void
	 * @since  1.0
	 */
	function field_link_text() {

		// get the options
		$options = get_option( 'gpaisrpro' );

		echo "<input id='gpaisrpro_link_text' name='gpaisrpro[link_text]' size='40' type='text' value='" . ( ( ! isset( $options['link_text'] ) ) ? 'Google+' : esc_attr( $options['link_text'] ) ) . "' />";

	}


	/**
	 * Includes some hidden fields
	 * @since 1.2
	 * @return void
	 */
	function fields_hidden() {
		echo '<input type="hidden" value="1" name="gpaisrpro[help_pointer]" />';
	}

	/**
	 * Displays the purchase code field
	 * @since 1.2
	 * @return void
	 */
	function field_purchase_code() {
		// get the options
		$options = get_option( 'gpaisrpro' );

		echo "<input id='gpaisrpro_purchase_code' name='gpaisrpro[purchase_code]' size='40' type='text' value='" . ( ( ! isset( $options['purchase_code'] ) ) ? '' : esc_attr( $options['purchase_code'] ) ) . "' />";
		echo '<p class="description">' . __( 'Enter your purchase code in order to get automatic updates!', $this->_google_author->get_textdomain() ) . ' <a target="_blank" href="http://wp-buddy.com/inlink/google-author-be-purchase-code">' . __( 'Click here if you do not know where to find your purchase code.', $this->_google_author->get_textdomain() ) . '</a></p>';
	}

	/**
	 * Returns the field for the Google Plus page
	 * @since 1.2
	 * @return void
	 */
	function field_google_plus_page_url() {
		// get the options
		$options = get_option( 'gpaisrpro' );

		echo "<input id='google_plus_page_url' name='gpaisrpro[google_plus_page_url]' size='40' type='text' value='" . ( ( ! isset( $options['google_plus_page_url'] ) ) ? '' : esc_attr( $options['google_plus_page_url'] ) ) . "' />";
		echo '<p class="description">' . __( 'Enter the URL to your Google+ page (if any) to link your Google+ page with your website.', $this->_google_author->get_textdomain() ) . ' <a target="_blank" href="http://wp-buddy.com/inlink/google-author-be-faq">' . __( 'Help: Click here to learn more about Google\'s Publishership (Question 10)', $this->_google_author->get_textdomain() ) . '</a></p>';
	}


	/**
	 * Returns the field for the Google Plus page
	 * @since 1.2
	 * @return void
	 */
	function field_google_plus_page_header() {
		// get the options
		$options = get_option( 'gpaisrpro' );

		if ( ! isset( $options['google_plus_page_header'] ) ) {
			$options['google_plus_page_header'] = 1;
		}

		echo "<input id='google_plus_page_header' name='gpaisrpro[google_plus_page_header]' type='radio' value='1' " . ( ( 1 == $options['google_plus_page_header'] ) ? 'checked="checked"' : '' ) . " /> <label for=\"google_plus_page_header\">" . __( 'In the header (not visible for the visitors)', $this->_google_author->get_textdomain() ) . '</label>';
		echo "<br /><input id='google_plus_page_footer' name='gpaisrpro[google_plus_page_header]' type='radio' value='0' " . ( ( 1 != $options['google_plus_page_header'] ) ? 'checked="checked"' : '' ) . " /> <label for=\"google_plus_page_footer\">" . __( 'In the footer', $this->_google_author->get_textdomain() ) . '</label>';
		echo '<p class="description">' . __( 'Whether the link should be displayed in the header (not visible to the visitor) rather than in the footer.', $this->_google_author->get_textdomain() ) . ' </p>';
	}


	/**
	 * @since 1.2
	 */
	function field_google_plus_page_text() {
		// get the options
		$options = get_option( 'gpaisrpro' );

		echo "<input id='google_plus_page_text' name='gpaisrpro[google_plus_page_text]' size='40' type='text' value='" . ( ( ! isset( $options['google_plus_page_text'] ) ) ? __( 'Our Google+ page', $this->_google_author->get_textdomain() ) : esc_attr( $options['google_plus_page_text'] ) ) . "' />";
	}


	/**
	 * @since 1.3
	 */
	function field_google_plus_page_styles() {
		// get the options
		$options = get_option( 'gpaisrpro' );

		echo "<input id='google_plus_page_text' name='gpaisrpro[google_plus_page_styles]' size='40' type='text' value='" . ( ( ! isset( $options['google_plus_page_styles'] ) ) ? 'color:#F5F5F5;text-align:center;font-size:10px;' : esc_attr( $options['google_plus_page_styles'] ) ) . "' />";
	}


	/**
	 * field_posts function.
	 * displays the show or hide settings field
	 *
	 * @access public
	 * @return void
	 * @since  1.3
	 */
	function field_posts() {
		echo '<select id="test_post_id" data-placeholder="' . __( 'Start typing to select a post', $this->_google_author->get_textdomain() ) . '" data-ajax_action="wpbga_ajax_postlist" data-ajax_nonce="' . wp_create_nonce( 'wp_ajax_wpbga_ajax_postlist' ) . '" class="chzn-select-ajax" style="width:300px;" name="gpaisrpro_test">';
		echo '<option value="" ></option></select>';
		echo ' <a id="testintegration" href="#" class="button">' . __( 'Start testing...', $this->_google_author->get_textdomain() ) . '</a>';
		echo ' <img class="wpbga_loader" id="wpbga_loader" src="' . $this->_google_author->plugins_url( 'assets/img/ajax-loader.gif' ) . '" alt="Loading" />';
	}


	/**
	 * @since 1.3
	 */
	function field_google_plus_frontpage_users() {
		echo '<select multiple="multiple" id="google_plus_frontpage_users" data-placeholder="' . __( 'Start typing to select a user', $this->_google_author->get_textdomain() ) . '" data-ajax_action="wpbga_ajax_userlist" data-ajax_nonce="' . wp_create_nonce( 'wp_ajax_wpbga_ajax_userlist' ) . '" class="chzn-select-ajax" style="width:300px;" name="gpaisrpro[google_plus_frontpage_users][]">';
		echo '<option value="" ></option>';

		$options = get_option( 'gpaisrpro' );
		if ( ! isset( $options['google_plus_frontpage_users'] ) ) {
			$options['google_plus_frontpage_users'] = array();
		}

		foreach ( $options['google_plus_frontpage_users'] as $user_id ) {
			/**
			 * the first value has to be lower case ('id' instead of 'ID')
			 * @var WP_User $user
			 */
			$user = get_user_by( 'id', $user_id );

			if ( ! $user instanceof WP_User ) {
				continue;
			}
			echo '<option value="' . $user_id . '" selected="selected">' . $user->get( 'display_name' ) . ' (' . $user->get( 'user_login' ) . ')</option>';
		}

		echo '</select>';
		echo ' <img class="wpbga_loader" src="' . $this->_google_author->plugins_url( 'assets/img/ajax-loader.gif' ) . '" alt="Loading" />';
		echo '<p class="description">' . __( 'Please select the users that will be displayed as authors for the front or home page.', $this->_google_author->get_textdomain() ) . '</p>';
	}

	/**
	 * @since 1.3
	 */
	function field_google_plus_category_users() {
		echo '<select multiple="multiple" id="google_plus_category_users" data-placeholder="' . __( 'Start typing to select a user', $this->_google_author->get_textdomain() ) . '" data-ajax_action="wpbga_ajax_userlist" data-ajax_nonce="' . wp_create_nonce( 'wp_ajax_wpbga_ajax_userlist' ) . '" class="chzn-select-ajax" style="width:300px;" name="gpaisrpro[google_plus_category_users][]">';
		echo '<option value="" ></option>';

		$options = get_option( 'gpaisrpro' );
		if ( ! isset( $options['google_plus_category_users'] ) ) {
			$options['google_plus_category_users'] = array();
		}

		foreach ( $options['google_plus_category_users'] as $user_id ) {
			/**
			 * the first value has to be lower case ('id' instead of 'ID')
			 * @var WP_User $user
			 */
			$user = get_user_by( 'id', $user_id );

			if ( ! $user instanceof WP_User ) {
				continue;
			}
			echo '<option value="' . $user_id . '" selected="selected">' . $user->get( 'display_name' ) . ' (' . $user->get( 'user_login' ) . ')</option>';
		}

		echo '</select>';
		echo ' <img class="wpbga_loader" src="' . $this->_google_author->plugins_url( 'assets/img/ajax-loader.gif' ) . '" alt="Loading" />';
		echo '<p class="description">' . __( 'Please select the users that will be displayed as authors for category pages.', $this->_google_author->get_textdomain() ) . '</p>';
	}

	/**
	 * @since 1.3
	 */
	function field_google_plus_tag_users() {
		echo '<select multiple="multiple" id="google_plus_tag_users" data-placeholder="' . __( 'Start typing to select a user', $this->_google_author->get_textdomain() ) . '" data-ajax_action="wpbga_ajax_userlist" data-ajax_nonce="' . wp_create_nonce( 'wp_ajax_wpbga_ajax_userlist' ) . '" class="chzn-select-ajax" style="width:300px;" name="gpaisrpro[google_plus_tag_users][]">';
		echo '<option value="" ></option>';

		$options = get_option( 'gpaisrpro' );
		if ( ! isset( $options['google_plus_tag_users'] ) ) {
			$options['google_plus_tag_users'] = array();
		}

		foreach ( $options['google_plus_tag_users'] as $user_id ) {
			/**
			 * the first value has to be lower case ('id' instead of 'ID')
			 * @var WP_User $user
			 */
			$user = get_user_by( 'id', $user_id );

			if ( ! $user instanceof WP_User ) {
				continue;
			}
			echo '<option value="' . $user_id . '" selected="selected">' . $user->get( 'display_name' ) . ' (' . $user->get( 'user_login' ) . ')</option>';
		}

		echo '</select>';
		echo ' <img class="wpbga_loader" src="' . $this->_google_author->plugins_url( 'assets/img/ajax-loader.gif' ) . '" alt="Loading" />';
		echo '<p class="description">' . __( 'Please select the users that will be displayed as authors for tag pages.', $this->_google_author->get_textdomain() ) . '</p>';
	}
}